pub struct JSONSourceMap {
pub file: Option<String>,
pub mappings: String,
pub source_root: Option<String>,
pub sources: Vec<String>,
pub sources_content: Option<Vec<Option<String>>>,
pub names: Vec<String>,
pub debug_id: Option<String>,
}Expand description
Fields
file: Option<String>An optional name of the generated code that this source map is associated with.
mappings: StringA string with the encoded mapping data.
source_root: Option<String>An optional source root, useful for relocating source files on a server or removing repeated values in the “sources” entry. This value is prepended to the individual entries in the “source” field.
sources: Vec<String>A list of original sources used by the “mappings” entry.
sources_content: Option<Vec<Option<String>>>An optional list of source content, useful when the “source” can’t be hosted. The contents are listed in the same order as the sources in line 5. “null” may be used if some original sources should be retrieved by name.
names: Vec<String>A list of symbol names used by the “mappings” entry.
debug_id: Option<String>An optional field containing the debugId for this sourcemap.